@@ -1,5 +1,5 @@
 /*******************************************************************************
- *  Copyright (c) 2000, 2018 IBM Corporation and others.
+ *  Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  *  This program and the accompanying materials
  *  are made available under the terms of the Eclipse Public License 2.0
@@ -442,6 +442,11 @@ public class StandardVMRunner extends AbstractVMRunner {
 			arguments.add(convertClassPath(cp));
 		}
 
+		// https://openjdk.java.net/jeps/12
+		if (config.isPreviewEnabled()) {
+			arguments.add("--enable-preview"); //$NON-NLS-1$
+		}
+
 		String dependencies = config.getOverrideDependencies();
 		if (dependencies != null && dependencies.length() > 0) {
 			String[] parseArguments = DebugPlugin.parseArguments(dependencies);
